pubtools-pulp
=============

A command-line interface to [Pulp](https://pulpproject.org/) tasks,
used by [release-engineering](https://github.com/release-engineering) publishing tools.

[![PyPI version](https://badge.fury.io/py/pubtools-pulp.svg)](https://badge.fury.io/py/pubtools-pulp)
[![Build Status](https://travis-ci.com/release-engineering/pubtools-pulp.svg?branch=master)](https://travis-ci.com/release-engineering/pubtools-pulp)
[![Coverage Status](https://coveralls.io/repos/github/release-engineering/pubtools-pulp/badge.svg?branch=master)](https://coveralls.io/github/release-engineering/pubtools-pulp?branch=master)

- [Source](https://github.com/release-engineering/pubtools-pulp)
- [Documentation](https://release-engineering.github.io/pubtools-pulp/)

License
-------

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
